/*
 * MikroSDK - MikroE Software Development Kit
 * Copyright (c) 2019, MikroElektronika - www.mikroe.com
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

/*!
 * \file
 *
 */

#include "slider2.h"


// ------------------------------------------------ PUBLIC FUNCTION DEFINITIONS

void slider2_cfg_setup ( slider2_cfg_t *cfg )
{
    // Communication gpio pins 

    cfg->an_pin = HAL_PIN_NC;
    
    // Additional gpio pins

    cfg->en   = HAL_PIN_NC;
    cfg->rsl = HAL_PIN_NC;

    cfg->channel      = ADC_CHANNEL_3;
    cfg->resolution   = ADC_RESOLUTION_DEFAULT;
    cfg->vref         = ADC_VREF_DEFAULT;
}

SLIDER2_RETVAL slider2_init ( slider2_t *ctx, slider2_cfg_t *cfg )
{
     analog_in_config_t adc_cfg;

    analog_in_configure_default( &adc_cfg );
    adc_cfg.pin        = cfg->an_pin;
    adc_cfg.channel    = cfg->channel;
    adc_cfg.resolution = cfg->resolution;
    adc_cfg.vref       = cfg->vref;
 
    if (  analog_in_open( &ctx->adc, &adc_cfg ) != ADC_SUCCESS )
    {
        return SLIDER2_INIT_ERROR;
    }

    // Output pins 

    digital_out_init( &ctx->en, cfg->en );
    digital_out_init( &ctx->rsl, cfg->rsl );


    return SLIDER2_OK;

}

void slider2_default_cfg ( slider2_t *ctx )
{
    slider2_enable( ctx, SLIDER2_DEVICE_ENABLE );
    slider2_set_reference( ctx, SLIDER2_MAX_VOLTAGE_2_048V );
}

slider2_data_t slider2_generic_read ( slider2_t *ctx )
{
    slider2_data_t rx_data;

    rx_data =  analog_in_read( &ctx->adc );
    
    return rx_data;
}

void slider2_enable ( slider2_t *ctx, uint8_t state )
{
    digital_out_write( &ctx->en, state );
}

void slider2_set_reference ( slider2_t *ctx, uint8_t ref )
{
    digital_out_write( &ctx->rsl, ref );
}

// ------------------------------------------------------------------------- END

